@@ -15,6 +15,15 @@ def ask_action_to_perform(workflow):
     return prompt_options("Select the action to perform:", options)
 
 
+def ask_build_type():
+    options = [
+        ("dummy", "Dummy build step"),
+        ("python_build", "Python wheel (.whl) and tar.gz package"),
+        ("hugo", "Static site with Hugo"),
+    ]
+    return prompt_options("Select the type of build to perform:", options)
+
+
 def ask_deployment_target():
     target = prompt_options(
         "Select deployment target:",
@@ -22,6 +31,7 @@ def ask_deployment_target():
             ("aws_s3", "AWS S3"),
             ("aws_lambda", "AWS Lambda"),
             ("pypi", "Publish to PyPI"),
+            ("github_pages", "GitHub Pages"),
         ],
     )
     return target
